@@ -38,6 +38,8 @@ class DependencyInfo(BaseModel):
     ignore_if_no_auth_id: bool
     require_user: bool
 
+    edge: str  # name of edge using
+
 
 FieldDepMapAlias = T.Dict[str, DependencyInfo]
 
@@ -491,7 +493,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     async def query(
         self, given_client: edgedb.AsyncIOClient = None, only_one: bool = False
-    ) -> T.Union[T.List[NodeType], NodeType, None]:
+    ) -> T.Union[T.List[NodeType], NodeType]:
         query_str = self.full_query_str()
         with safe_span(
             op=f"edgedb.query.{self._model_name}", description=query_str[:200]
